#include "TestApp.h"

#include <iostream>
#include <fstream>

vector<string> fk_StrSplit(string argStr, string argToken)
{
	vector<string>		retStrArray;
	string::size_type	curPos = 0, nextPos = 0;

	while(nextPos != string::npos) {
		nextPos = argStr.find(argToken, curPos);
		retStrArray.push_back(argStr.substr(curPos, nextPos-curPos));
		curPos = nextPos+argToken.size();
	}

	return retStrArray;
}

TestApp::TestApp(Fl_Window *argMainWin, fk_Window *argDrawWin)
	: fkut_AppBase(argMainWin, argDrawWin)
{
}

TestApp::~TestApp(void)
{
}

void TestApp::init(void)
{
	lightModel.setShape(&light);
	lightModel.glFocus(1.0, -1.0, -1.0);
	lightModel.setMaterial(White);

	block.setSize(50.0, 50.0, 50.0);
	blockModel.setShape(&block);
	blockModel.setMaterial(Yellow);

	camera.glMoveTo(0.0, 0.0, 500.0);
	camera.glFocus(0.0, 0.0, 0.0);

	scene.entryCamera(&camera);
	scene.entryModel(&lightModel);
	scene.entryModel(&blockModel);

	drawWin->setScene(&scene);

	sinkuHadouken.setLimit(500);
	sinkuHadouken.pushCommand(0, FKUT_DIR2, FKUT_SW_PRESS);
	sinkuHadouken.pushCommand(1, FKUT_DIR3, FKUT_SW_PRESS);
	sinkuHadouken.pushCommand(2, FKUT_DIR6, FKUT_SW_PRESS);
	sinkuHadouken.pushCommand(3, FKUT_DIR2, FKUT_SW_PRESS);
	sinkuHadouken.pushCommand(4, FKUT_DIR3, FKUT_SW_PRESS);
	sinkuHadouken.pushCommand(5, FKUT_DIR6, FKUT_SW_PRESS);
	sinkuHadouken.pushCommand(5,         0, FKUT_SW_DOWN);

	shouryuken.setLimit(500);
	shouryuken.pushCommand(0, FKUT_DIR6, FKUT_SW_PRESS);
	shouryuken.pushCommand(1, FKUT_DIR2, FKUT_SW_PRESS);
	shouryuken.pushCommand(2, FKUT_DIR3, FKUT_SW_PRESS);
	shouryuken.pushCommand(2,         0, FKUT_SW_DOWN);

	hadouken.setLimit(500);
	hadouken.pushCommand(0, FKUT_DIR2, FKUT_SW_PRESS);
	hadouken.pushCommand(1, FKUT_DIR3, FKUT_SW_PRESS);
	hadouken.pushCommand(2, FKUT_DIR6, FKUT_SW_PRESS);
	hadouken.pushCommand(2,         0, FKUT_SW_DOWN);

	dash.setLimit(500);
	dash.pushCommand(0, FKUT_DIR6, FKUT_SW_DOWN);
	dash.pushCommand(1, FKUT_DIR5, FKUT_SW_DOWN);
	dash.pushCommand(2, FKUT_DIR6, FKUT_SW_DOWN);

	nage.setLimit(16);
	nage.pushCommand(0, 0, FKUT_SW_DOWN);
	nage.pushCommand(0, 1, FKUT_SW_DOWN);

	return;
}

bool TestApp::procLoop(void)
{
	blockModel.glRotateWithVec(0.0, 0.0, 0.0, fk_Y, 0.1);

	if(sinkuHadouken.check(&eveMan)) cout << "񂭁[͂ǁ[I" << endl;
	if(shouryuken.check(&eveMan)) cout << "[[I" << endl;
	if(hadouken.check(&eveMan)) cout << "͂ǁ[I" << endl;
	if(dash.check(&eveMan)) cout << "_bV" << endl;
	if(nage.check(&eveMan)) cout << "" << endl;

	return true;
}
